simplelock — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

Home | Table of contents | Index | Modules
« previous | up | next »

# `simplelock`

## Models

class `Lock`(*args, **kwargs)

  A lock on something.

  This usually denotes something that someone is working on and shouldn’t be touched by others.

« <tt class="docutils literal docutils literal docutils literal"><span class="pre">simpleauth</span></tt> | up | <tt class="docutils literal"><span class="pre">tarball</span></tt> »

### Table Of Contents

- `simplelock`
  - Models

### Browse

- Prev: `simpleauth`
- Next: `tarball`

### You are here:

- Transifex v0.8.0 documentation
  - Table of Contents
    - Transifex Modules
      - `simplelock`

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Last update:

Mar 02, 2010

« previous | up | next »
© Copyright Indifex and the Transifex Community. Last updated on Mar 02, 2010 using Sphinx.